pub enum ApprovalRecoveryState {
DecisionRecorded(RecordedApprovalRecovery),
RepromptRequired,
}Expand description
The recovery state for an approval occurrence.
Variants
DecisionRecorded(RecordedApprovalRecovery)
A verified decision is ready for a resume turn.
RepromptRequired
The prior response was unverifiable, so the durable turn will re-prompt.